# Sequence containers

![mkapi](picea.Alphabet)

![mkapi](picea.Sequence)

![mkapi](picea.SequenceCollection)

![mkapi](picea.SequenceList)

![mkapi](picea.MultipleSequenceAlignment)

![mkapi](picea.SequenceAnnotation)